@@ -3,8 +3,9 @@ Main interface for appsync service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.appsync import (
+    from mypy_boto3_appsync import (
         AppSyncClient,
         Client,
         ListApiKeysPaginator,
@@ -14,7 +15,7 @@ Usage::
         ListResolversByFunctionPaginator,
         ListResolversPaginator,
         ListTypesPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -28,6 +29,7 @@ Usage::
     list_resolvers_paginator: ListResolversPaginator = client.get_paginator("list_resolvers")
     list_resolvers_by_function_paginator: ListResolversByFunctionPaginator = client.get_paginator("list_resolvers_by_function")
     list_types_paginator: ListTypesPaginator = client.get_paginator("list_types")
+    ```
 """
 from mypy_boto3_appsync.client import AppSyncClient as Client, AppSyncClient
 from mypy_boto3_appsync.paginator import (
