@@ -3,9 +3,11 @@ Main interface for appsync service type definitions.
 
 Usage::
 
-    from mypy_boto3.appsync.type_defs import AdditionalAuthenticationProviderTypeDef
+    ```python
+    from mypy_boto3_appsync.type_defs import AdditionalAuthenticationProviderTypeDef
 
     data: AdditionalAuthenticationProviderTypeDef = {...}
+    ```
 """
 import sys
 from typing import Dict, List
